@@ -1,3 +1,4 @@
+from typing import Any
 from elasticsearch import Elasticsearch
 from robot.api import logger
 from datetime import datetime
@@ -23,7 +24,7 @@ class Elastic:
         self.index = datetime.today().strftime(
             f"robot-logs-{ENVIRONMENT}-{CLIENT}-{ROBOT_NAME}-%Y.%m")
 
-    def publish(self, message, **fields):
+    def publish(self, message: str, **fields: Any):
         timestamp = datetime.now(self.tz)
         doc = {
             "message": message,
